// dictionary.h
// 
// A simple and robust dynamic dictionary implementation in ANSI C using pages and hash values
// for faster access to the data.
// 
// This code is very easily portable to C++.


#ifndef DICTIONARY_H
#define DICTIONARY_H


#include <stdio.h>
#include <ctype.h>
#include <malloc.h>
#include <string.h>


#define DICTIONARY_PAGE_SIZE 128
#define DICTIONARY_INVALID_KEY ((char *) -1)


typedef struct dictionary_entry_s
{
   char *key; // key string (mallocated)
   unsigned long hash; // key hash value
   char *value; // value string (mallocated)
} dictionary_entry_t;


typedef struct dictionary_s
{
   int size; // storage size
   dictionary_entry_t *entries; // array of entries (mallocated)
   int entry_count; // number of entries in dictionary
} dictionary_t;


// dictionary.c function prototypes
dictionary_t *Dictionary_CreateDictionary (int size);
void Dictionary_DestroyDictionary (dictionary_t *dictionary);
char *Dictionary_ReadKey (dictionary_t *dictionary, char *key, char *default_value);
void Dictionary_WriteKey (dictionary_t *dictionary, char *key, char *value);
void Dictionary_DeleteKey (dictionary_t *dictionary, char *key);


#endif // DICTIONARY_H
