// inifile.h
// 
// A simple and robust INI reader/writer implementation in ANSI C using a fast underlying
// dictionary structure.
// 
// This code is very easily portable to C++.


#ifndef INIFILE_H
#define INIFILE_H


#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "dictionary.h"


// we code in ANSI C, here.
#define false 0
#define true 1
#define bool unsigned char


// iniparser.c function prototypes
int INIFile_GetNumberOfSections (dictionary_t *dictionary);
char *INIFile_GetSectionName (dictionary_t *dictionary, int section_index);
bool INIFile_ReadEntryAsBool (dictionary_t *dictionary, char *section, char *entry, bool default_value);
long INIFile_ReadEntryAsLong (dictionary_t *dictionary, char *section, char *entry, long default_value);
double INIFile_ReadEntryAsDouble (dictionary_t *dictionary, char *section, char *entry, double default_value);
char *INIFile_ReadEntryAsString (dictionary_t *dictionary, char *section, char *entry, char *default_value);
void INIFile_WriteEntryAsBool (dictionary_t *dictionary, char *section, char *entry, bool value);
void INIFile_WriteEntryAsLong (dictionary_t *dictionary, char *section, char *entry, long value);
void INIFile_WriteEntryAsDouble (dictionary_t *dictionary, char *section, char *entry, double value);
void INIFile_WriteEntryAsString (dictionary_t *dictionary, char *section, char *entry, char *value);
void INIFile_DeleteEntry (dictionary_t *dictionary, char *section, char *entry);
void INIFile_DeleteSection (dictionary_t *dictionary, char *section);
void INIFile_LoadINIFile (char *filename, dictionary_t *dictionary);
void INIFile_SaveINIFile (char *filename, dictionary_t *dictionary);


#endif // INIFILE_H
